@@ -213,6 +213,10 @@ class Store(StorageInterface):
                     raise StoreLockError(exc)
                 time.sleep(.1)
 
+        # Protect against incoming tiddlers that have revision
+        # set. Since we are putting a new one, we want the system
+        # to calculate.
+        tiddler.revision = None
         revision = self._tiddler_revision_filename(tiddler) + 1
         tiddler_filename = self._tiddler_full_filename(tiddler, revision)
 
@@ -285,8 +289,8 @@ class Store(StorageInterface):
         path = os.path.join(self._store_root(), 'recipes')
         recipes = self._files_in_dir(path)
 
-        return [Recipe(urllib.unquote(recipe).decode('utf-8'))
-                for recipe in recipes]
+        return (Recipe(urllib.unquote(recipe).decode('utf-8'))
+                for recipe in recipes)
 
     def list_bags(self):
         """
@@ -294,7 +298,7 @@ class Store(StorageInterface):
         """
         bags = self._bag_filenames()
 
-        return [Bag(urllib.unquote(bag).decode('utf-8')) for bag in bags]
+        return (Bag(urllib.unquote(bag).decode('utf-8')) for bag in bags)
 
     def list_users(self):
         """
@@ -303,7 +307,7 @@ class Store(StorageInterface):
         path = os.path.join(self._store_root(), 'users')
         users = self._files_in_dir(path)
 
-        return [User(urllib.unquote(user).decode('utf-8')) for user in users]
+        return (User(urllib.unquote(user).decode('utf-8')) for user in users)
 
     def list_tiddler_revisions(self, tiddler):
         """
@@ -313,8 +317,8 @@ class Store(StorageInterface):
         tiddler_base_filename = self._tiddler_base_filename(tiddler)
         try:
             revisions = sorted(
-                    [int(x) for x in
-                        self._numeric_files_in_dir(tiddler_base_filename)])
+                    int(x) for x in
+                        self._numeric_files_in_dir(tiddler_base_filename))
         except OSError, exc:
             raise NoTiddlerError('unable to list revisions in tiddler: %s'
                     % exc)
@@ -377,14 +381,14 @@ class Store(StorageInterface):
         """
         List the filenames in a dir that do not start with .
         """
-        return [x for x in os.listdir(path) if not x.startswith('.')]
+        return (x for x in os.listdir(path) if not x.startswith('.'))
 
     def _numeric_files_in_dir(self, path):
         """
         List the filename in a dir that are not made up of
         digits.
         """
-        return [x for x in self._files_in_dir(path) if x.isdigit()]
+        return (x for x in self._files_in_dir(path) if x.isdigit())
 
     def _read_tiddler_file(self, tiddler, tiddler_filename):
         """
