@@ -99,34 +99,6 @@ def get_tiddlers(environ, start_response):
     return send_tiddlers(environ, start_response, tmp_bag)
 
 
-def import_wiki(environ, start_response):
-    """
-    Accept a tiddlywiki as POST and using it as the source
-    parse it for tiddlers to be stored in the named bag.
-    """
-    bag_name = _determine_bag_name(environ)
-    bag = _get_bag(environ, bag_name, True)
-    length = environ['CONTENT_LENGTH']
-    content = environ['wsgi.input'].read(int(length))
-
-    bag.policy.allows(environ['tiddlyweb.usersign'], 'create')
-
-    try:
-        serialize_type, mime_type = web.get_serialize_type(environ)
-        serializer = Serializer(serialize_type, environ)
-        serializer.object = bag
-
-        serializer.from_string(content)
-    except NoSerializationError:
-        raise HTTP415('Content type not supported: %s' % mime_type)
-    except AttributeError, exc:
-        raise HTTP400('Content malformed: %s' % exc)
-
-    start_response("204 No Content",
-            [('Location', '%s/tiddlers' % web.bag_url(environ, bag))])
-    return ['']
-
-
 def list(environ, start_response):
     """
     List all the bags that the current user can read.
@@ -143,19 +115,16 @@ def list(environ, start_response):
         except(UserRequiredError, ForbiddenError):
             pass
 
+    serialize_type, mime_type = web.get_serialize_type(environ)
+    start_response("200 OK", [('Content-Type', mime_type)])
+    serializer = Serializer(serialize_type, environ)
+
     try:
-        serialize_type, mime_type = web.get_serialize_type(environ)
-        serializer = Serializer(serialize_type, environ)
-
-        content = serializer.list_bags(kept_bags)
-
-    except NoSerializationError:
-        raise HTTP415('Content type not supported: %s' % mime_type)
-
-    start_response("200 OK",
-            [('Content-Type', mime_type)])
-
-    return [content]
+        output = serializer.list_bags(kept_bags)
+    except NoSerializationError, exc:
+        raise HTTP415('Content type not supported: %s, %a' % (mime_type, exc))
+    
+    return [output]
 
 
 def put(environ, start_response):
